@@ -9,22 +9,21 @@ from .util.string import convert_to_underscore
 _LOGGER = logging.getLogger(__name__)
 
 
-class SystemStates(Enum):
-    """Define states that the system can be in."""
-
-    away = 1
-    away_count = 2
-    entry_delay = 3
-    exit_delay = 4
-    home = 5
-    home_count = 5
-    off = 6
-    unknown = 99
-
-
 class System:
     """Define a system."""
 
+    class SystemStates(Enum):
+        """Define states that the system can be in."""
+
+        away = 1
+        away_count = 2
+        entry_delay = 3
+        exit_delay = 4
+        home = 5
+        home_count = 5
+        off = 6
+        unknown = 99
+
     def __init__(self, account, location_info: dict) -> None:
         """Initialize."""
         self._location_info = location_info
@@ -33,10 +32,10 @@ class System:
 
         try:
             raw_state = location_info['system']['alarmState']
-            self._state = SystemStates[convert_to_underscore(raw_state)]
+            self._state = self.SystemStates[convert_to_underscore(raw_state)]
         except KeyError:
             _LOGGER.error('Unknown alarm state: %s', raw_state)
-            self._state = SystemStates.unknown
+            self._state = self.SystemStates.unknown
 
     @property
     def alarm_going_off(self) -> bool:
@@ -49,7 +48,7 @@ class System:
         return self._location_info['system']['serial']
 
     @property
-    def state(self) -> SystemStates:
+    def state(self) -> Enum:
         """Return the current state of the system."""
         return self._state
 
@@ -76,8 +75,7 @@ class System:
         """Update information on the system."""
         subscription_resp = await self.account.get_subscription_data()
         [location_info] = [
-            system['location']
-            for system in subscription_resp['subscriptions']
+            system['location'] for system in subscription_resp['subscriptions']
             if system['sid'] == self.system_id
         ]
         self._location_info = location_info
@@ -100,15 +98,15 @@ class System:
 
     async def set_away(self) -> None:
         """Set the system in "Away" mode."""
-        await self._set_state(SystemStates.away)
+        await self._set_state(self.SystemStates.away)
 
     async def set_home(self) -> None:
         """Set the system in "Home" mode."""
-        await self._set_state(SystemStates.home)
+        await self._set_state(self.SystemStates.home)
 
     async def set_off(self) -> None:
         """Set the system in "Off" mode."""
-        await self._set_state(SystemStates.off)
+        await self._set_state(self.SystemStates.off)
 
     async def update(
             self, refresh_location: bool = True, cached: bool = True) -> None:
@@ -119,7 +117,7 @@ class System:
 class SystemV2(System):
     """Define a V2 (original) system."""
 
-    async def _set_state(self, value: SystemStates) -> None:
+    async def _set_state(self, value: Enum) -> None:
         """Set the state of the system."""
         if self._state == value:
             return
@@ -130,7 +128,7 @@ class SystemV2(System):
             params={'state': value.name})
 
         if resp['success']:
-            self._state = SystemStates[resp['requestedState']]
+            self._state = self.SystemStates[resp['requestedState']]
 
     async def update(
             self, refresh_location: bool = True, cached: bool = True) -> None:
@@ -160,7 +158,7 @@ class SystemV2(System):
 class SystemV3(System):
     """Define a V3 (new) system."""
 
-    async def _set_state(self, value: SystemStates) -> None:
+    async def _set_state(self, value: Enum) -> None:
         """Set the state of the system."""
         if self._state == value:
             return
@@ -169,7 +167,7 @@ class SystemV3(System):
             'post', 'ss3/subscriptions/{0}/state/{1}'.format(
                 self.system_id, value.name))
 
-        self._state = SystemStates[convert_to_underscore(resp['state'])]
+        self._state = self.SystemStates[convert_to_underscore(resp['state'])]
 
     async def update(
             self, refresh_location: bool = True, cached: bool = True) -> None:
